summaryrefslogtreecommitdiffstats
path: root/kopete/kopete/chatwindow/emoticonselector.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/kopete/chatwindow/emoticonselector.cpp')
-rw-r--r--kopete/kopete/chatwindow/emoticonselector.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/kopete/kopete/chatwindow/emoticonselector.cpp b/kopete/kopete/chatwindow/emoticonselector.cpp
index 719068d0..015f2f5c 100644
--- a/kopete/kopete/chatwindow/emoticonselector.cpp
+++ b/kopete/kopete/chatwindow/emoticonselector.cpp
@@ -32,12 +32,12 @@
#include <kdebug.h>
-EmoticonLabel::EmoticonLabel(const TQString &emoticonText, const TQString &pixmapPath, TQWidget *parent, const char *name)
- : TQLabel(parent,name)
+EmoticonLabel::EmoticonLabel(const TQString &emoticonText, const TQString &pixmapPath, TQWidget *tqparent, const char *name)
+ : TQLabel(tqparent,name)
{
mText = emoticonText;
setMovie( TQMovie(pixmapPath) );
- setAlignment(Qt::AlignCenter);
+ tqsetAlignment(TQt::AlignCenter);
TQToolTip::add(this,emoticonText);
// Somehow TQLabel doesn't tell a reasonable size when you use setMovie
// although it does it correctly for setPixmap. Therefore here is a little workaround
@@ -57,8 +57,8 @@ void EmoticonLabel::mouseReleaseEvent(TQMouseEvent*)
emit clicked(mText);
}
-EmoticonSelector::EmoticonSelector(TQWidget *parent, const char *name)
- : TQWidget(parent, name)
+EmoticonSelector::EmoticonSelector(TQWidget *tqparent, const char *name)
+ : TQWidget(tqparent, name)
{
// kdDebug(14000) << k_funcinfo << "called." << endl;
lay = 0L;
@@ -100,18 +100,18 @@ void EmoticonSelector::prepareList(void)
else
col++;
}
- resize(minimumSizeHint());
+ resize(tqminimumSizeHint());
}
void EmoticonSelector::emoticonClicked(const TQString &str)
{
// kdDebug(14000) << "selected emoticon '" << str << "'" << endl;
// KDE4/Qt TODO: use qobject_cast instead.
emit ItemSelected ( str );
- if ( isVisible() && parentWidget() &&
- parentWidget()->inherits(TQPOPUPMENU_OBJECT_NAME_STRING) )
+ if ( isVisible() && tqparentWidget() &&
+ tqparentWidget()->inherits(TQPOPUPMENU_OBJECT_NAME_STRING) )
{
- parentWidget()->close();
+ tqparentWidget()->close();
}
}
@@ -100,18 +100,18 @@ void EmoticonSelector::prepareList(void)
{
// kdDebug(14000) << "selected emoticon '" << str << "'" << endl;
- // KDE4/Qt TODO: use qobject_cast instead.
+ // KDE4/TQt TODO: use qobject_cast instead.
emit ItemSelected ( str );